@@ -77,7 +77,9 @@ class BootImageKiwi(BootImageBase):
             root_dir=self.boot_root_directory,
             allow_existing=True
         )
-        manager = system.setup_repositories(signing_keys=self.signing_keys)
+        manager = system.setup_repositories(
+            signing_keys=self.signing_keys, target_arch=self.target_arch
+        )
         system.install_bootstrap(
             manager
         )
