@@ -19,6 +19,7 @@ import os
 import logging
 from tempfile import mkdtemp
 from tempfile import NamedTemporaryFile
+from typing import Dict
 import shutil
 
 # project
@@ -27,6 +28,7 @@ from kiwi.filesystem import FileSystem
 from kiwi.filesystem.isofs import FileSystemIsoFs
 from kiwi.filesystem.setup import FileSystemSetup
 from kiwi.storage.loop_device import LoopDevice
+from kiwi.storage.device_provider import DeviceProvider
 from kiwi.boot.image.dracut import BootImageDracut
 from kiwi.system.size import SystemSize
 from kiwi.system.setup import SystemSetup
@@ -39,10 +41,9 @@ from kiwi.system.identifier import SystemIdentifier
 from kiwi.system.kernel import Kernel
 from kiwi.runtime_config import RuntimeConfig
 from kiwi.iso_tools.base import IsoToolsBase
+from kiwi.xml_state import XMLState
 
-from kiwi.exceptions import (
-    KiwiLiveBootImageError
-)
+from kiwi.exceptions import KiwiLiveBootImageError
 
 log = logging.getLogger('kiwi')
 
@@ -56,9 +57,12 @@ class LiveImageBuilder:
     :param str root_dir: root directory path name
     :param dict custom_args: Custom processing arguments
     """
-    def __init__(self, xml_state, target_dir, root_dir, custom_args=None):
-        self.media_dir = None
-        self.live_container_dir = None
+    def __init__(
+        self, xml_state: XMLState, target_dir: str,
+        root_dir: str, custom_args: Dict = None
+    ):
+        self.media_dir: str = ''
+        self.live_container_dir: str = ''
         self.arch = Defaults.get_platform_name()
         self.root_dir = root_dir
         self.target_dir = target_dir
@@ -96,7 +100,7 @@ class LiveImageBuilder:
         self.result = Result(xml_state)
         self.runtime_config = RuntimeConfig()
 
-    def create(self):
+    def create(self) -> Result:
         """
         Build a bootable hybrid live ISO image
 
@@ -239,7 +243,9 @@ class LiveImageBuilder:
             '--> Syncing data to {0} root image'.format(root_filesystem)
         )
         live_filesystem.sync_data(
-            Defaults.get_exclude_list_for_root_data_sync()
+            Defaults.
+            get_exclude_list_for_root_data_sync() + Defaults.
+            get_exclude_list_from_custom_exclude_files(self.root_dir)
         )
         live_filesystem.umount()
 
@@ -253,7 +259,7 @@ class LiveImageBuilder:
         )
         live_container_image = FileSystem.new(
             name='squashfs',
-            device_provider=None,
+            device_provider=DeviceProvider(),
             root_dir=self.live_container_dir,
             custom_args={
                 'compression':
@@ -272,7 +278,7 @@ class LiveImageBuilder:
         # create iso filesystem from media_dir
         log.info('Creating live ISO image')
         iso_image = FileSystemIsoFs(
-            device_provider=None, root_dir=self.media_dir,
+            device_provider=DeviceProvider(), root_dir=self.media_dir,
             custom_args=custom_iso_args
         )
         iso_image.create_on_file(self.isoname)
@@ -321,7 +327,7 @@ class LiveImageBuilder:
         )
         return self.result
 
-    def _setup_live_iso_kernel_and_initrd(self):
+    def _setup_live_iso_kernel_and_initrd(self) -> None:
         """
         Copy kernel and initrd from the root tree into the iso boot structure
         """
@@ -363,7 +369,7 @@ class LiveImageBuilder:
                 )
             )
 
-    def __del__(self):
+    def __del__(self) -> None:
         if self.media_dir or self.live_container_dir:
             log.info(
                 'Cleaning up {0} instance'.format(type(self).__name__)
