@@ -24,7 +24,7 @@ class FileSystemFat16(FileSystemBase):
     """
     **Implements creation of fat16 filesystem**
     """
-    def create_on_device(self, label=None):
+    def create_on_device(self, label: str = None):
         """
         Create fat16 filesystem on block device
 
