@@ -26,6 +26,8 @@ import glob
 import os
 
 # project
+import kiwi.defaults as defaults
+
 from kiwi.exceptions import KiwiUriOpenError
 from kiwi.path import Path
 from kiwi.command import Command
@@ -137,11 +139,72 @@ class SolverRepositoryBase:
             location = urlopen(request)
         except Exception as e:
             raise KiwiUriOpenError(
-                '{0}: {1} {2}'.format(type(e).__name__, format(e), download_link)
+                f'{type(e).__name__}: {e} {download_link}'
             )
         with open(target, 'wb') as target_file:
             target_file.write(location.read())
 
+    def get_repo_type(self):
+        try:
+            if self._get_repomd_xml():
+                return 'rpm-md'
+        except KiwiUriOpenError:
+            pass
+        try:
+            if self._get_deb_packages():
+                return 'apt-deb'
+        except KiwiUriOpenError:
+            pass
+        try:
+            repo_listing = self._get_pacman_packages()
+            if '.db.sig\"' in repo_listing:
+                return 'pacman'
+        except KiwiUriOpenError:
+            pass
+        return None
+
+    def _get_pacman_packages(self):
+        """
+        Download Arch repository listing for the current architecture
+
+        :return: html directory listing
+
+        :rtype: str
+        """
+        dir_listing_download = NamedTemporaryFile()
+        self.download_from_repository(
+            defaults.PLATFORM_MACHINE, dir_listing_download.name
+        )
+        if os.path.isfile(dir_listing_download.name):
+            with open(dir_listing_download.name) as listing:
+                return listing.read()
+
+    def _get_deb_packages(self, download_dir=None):
+        """
+        Download Packages.gz file from an apt repository and
+        return its contents. If download_dir is set, download
+        the file and return the file path name
+
+        :param str download_dir: Download directory
+
+        :return: Contents of Packages file or file path name
+
+        :rtype: str
+        """
+        repo_source = 'Packages.gz'
+        if not download_dir:
+            packages_download = NamedTemporaryFile()
+            self.download_from_repository(repo_source, packages_download.name)
+            if os.path.isfile(packages_download.name):
+                with open(packages_download.name) as packages:
+                    return packages.read()
+        else:
+            packages_download = os.sep.join(
+                [download_dir, repo_source.replace(os.sep, '_')]
+            )
+            self.download_from_repository(repo_source, packages_download)
+            return packages_download
+
     def _get_repomd_xml(self, lookup_path='repodata'):
         """
         Parse repomd.xml file from lookup_path and return an etree
@@ -212,6 +275,9 @@ class SolverRepositoryBase:
         * rpms2solv
           solvable from rpm header files
 
+        * deb2solv
+          solvable from deb header files
+
         :param str metadata_dir: path name
         :param str tool: one of the above tools
         """
@@ -228,9 +294,13 @@ class SolverRepositoryBase:
         else:
             # each file in the metadata_dir is considered a valid
             # solvable for the selected solv tool
+            tool_options = []
+            if tool == 'deb2solv':
+                tool_options.append('-r')
             for source in glob.iglob('/'.join([metadata_dir, '*'])):
                 bash_command = [
-                    'gzip', '-cd', '--force', source, '|', tool,
+                    'gzip', '-cd', '--force', source, '|', tool
+                ] + tool_options + [
                     '>', self._get_random_solvable_name()
                 ]
                 Command.run(['bash', '-c', ' '.join(bash_command)])
